# -*- Mode: python; tab-width: 4; indent-tabs-mode:nil; coding: utf-8 -*-
# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4

# colormap from http://jmol.sourceforge.net/jscolors/
atoms_maps = {
    'H':  {'number': 1,  'color': [255, 255, 255], 'mass': 1.0079},
    'He': {'number': 2,  'color': [217, 255, 255], 'mass': 4.0026},
    'Li': {'number': 3,  'color': [204, 128, 255], 'mass': 6.941},
    'Be': {'number': 4,  'color': [194, 255, 0],   'mass': 9.0122},
    'B':  {'number': 5,  'color': [255, 181, 181], 'mass': 10.811},
    'C':  {'number': 6,  'color': [144, 144, 144], 'mass': 12.0107},
    'N':  {'number': 7,  'color': [48, 80, 248],   'mass': 14.0067},
    'O':  {'number': 8,  'color': [255, 13, 13],   'mass': 15.9994},
    'F':  {'number': 9,  'color': [144, 224, 80],  'mass': 18.9984},
    'Ne': {'number': 10, 'color': [179, 227, 245], 'mass': 20.1797},
    'Na': {'number': 11, 'color': [171, 92, 242],  'mass': 22.9897},
    'Mg': {'number': 12, 'color': [138, 255, 0],   'mass': 24.305},
    'Al': {'number': 13, 'color': [191, 166, 166], 'mass': 26.9815},
    'Si': {'number': 14, 'color': [240, 200, 160], 'mass': 28.0855},
    'P':  {'number': 15, 'color': [255, 128, 0],   'mass': 30.9738},
    'S':  {'number': 16, 'color': [255, 255, 48],  'mass': 32.065},
    'Cl': {'number': 17, 'color': [31, 240, 31],   'mass': 35.453},
    'Ar': {'number': 18, 'color': [128, 209, 227], 'mass': 39.948},
    'K':  {'number': 19, 'color': [143, 64, 212],  'mass': 39.0983},
    'Ca': {'number': 20, 'color': [61, 255, 0],    'mass': 40.078},
    'Sc': {'number': 21, 'color': [230, 230, 230], 'mass': 44.9559},
    'Ti': {'number': 22, 'color': [191, 194, 199], 'mass': 47.867},
    'V':  {'number': 23, 'color': [166, 166, 171], 'mass': 50.9415},
    'Cr': {'number': 34, 'color': [138, 153, 199], 'mass': 51.9961},
    'Mn': {'number': 25, 'color': [156, 122, 199], 'mass': 54.938},
    'Fe': {'number': 26, 'color': [224, 102, 51],  'mass': 55.845},
    'Co': {'number': 27, 'color': [240, 144, 160], 'mass': 58.9332},
    'Ni': {'number': 28, 'color': [80, 208, 80],   'mass': 58.6934},
    'Cu': {'number': 29, 'color': [200, 128, 51],  'mass': 63.546},
    'Zn': {'number': 30, 'color': [125, 128, 176], 'mass': 65.39},
    'Ga': {'number': 31, 'color': [194, 143, 143], 'mass': 69.723},
    'Ge': {'number': 32, 'color': [102, 143, 143], 'mass': 72.64},
    'As': {'number': 33, 'color': [189, 128, 227], 'mass': 74.9216},
    'Se': {'number': 34, 'color': [255, 161, 0],   'mass': 78.96},
    'Br': {'number': 35, 'color': [166, 41, 41],   'mass': 79.904},
    'Kr': {'number': 36, 'color': [92, 184, 209],  'mass': 83.8},
    'Rb': {'number': 37, 'color': [112, 46, 176],  'mass': 85.4678},
    'Sr': {'number': 38, 'color': [0, 255, 0],     'mass': 87.62},
    'Y':  {'number': 39, 'color': [148, 255, 255], 'mass': 88.9059},
    'Zr': {'number': 40, 'color': [148, 224, 224], 'mass': 91.224},
    'Nb': {'number': 41, 'color': [115, 194, 201], 'mass': 92.9064},
    'Mo': {'number': 42, 'color': [84, 181, 181],  'mass': 95.94},
    'Tc': {'number': 43, 'color': [59, 158, 158],  'mass': 98.0},
    'Ru': {'number': 44, 'color': [36, 143, 143],  'mass': 101.07},
    'Rh': {'number': 45, 'color': [10, 125, 140],  'mass': 102.906},
    'Pd': {'number': 46, 'color': [0, 105, 133],   'mass': 106.42},
    'Ag': {'number': 47, 'color': [192, 192, 192], 'mass': 107.868},
    'Cd': {'number': 48, 'color': [255, 217, 143], 'mass': 112.411},
    'In': {'number': 49, 'color': [166, 117, 115], 'mass': 114.818},
    'Sn': {'number': 50, 'color': [102, 128, 128], 'mass': 118.71},
    'Sb': {'number': 51, 'color': [158, 99, 181],  'mass': 121.76},
    'Te': {'number': 52, 'color': [212, 122, 0],   'mass': 127.6},
    'I':  {'number': 53, 'color': [148, 0, 148],   'mass': 126.905},
    'Xe': {'number': 54, 'color': [66, 158, 176],  'mass': 131.293},
    'Cs': {'number': 55, 'color': [87, 23, 143],   'mass': 132.906},
    'Ba': {'number': 56, 'color': [0, 201, 0],     'mass': 137.327},
    'La': {'number': 57, 'color': [112, 212, 255], 'mass': 138.906},
    'Ce': {'number': 58, 'color': [255, 255, 199], 'mass': 140.116},
    'Pr': {'number': 59, 'color': [217, 255, 199], 'mass': 140.908},
    'Nd': {'number': 60, 'color': [199, 255, 199], 'mass': 144.24},
    'Pm': {'number': 61, 'color': [163, 255, 199], 'mass': 145.0},
    'Sm': {'number': 62, 'color': [143, 255, 199], 'mass': 150.36},
    'Eu': {'number': 63, 'color': [97, 255, 199],  'mass': 151.964},
    'Gd': {'number': 64, 'color': [69, 255, 199],  'mass': 157.25},
    'Tb': {'number': 65, 'color': [48, 255, 199],  'mass': 158.925},
    'Dy': {'number': 66, 'color': [31, 255, 199],  'mass': 162.5},
    'Ho': {'number': 67, 'color': [0, 255, 156],   'mass': 164.930},
    'Er': {'number': 68, 'color': [0, 230, 117],   'mass': 167.259},
    'Tm': {'number': 69, 'color': [0, 212, 82],    'mass': 168.934},
    'Yb': {'number': 70, 'color': [0, 191, 56],    'mass': 173.04},
    'Lu': {'number': 71, 'color': [0, 171, 36],    'mass': 174.967},
    'Hf': {'number': 72, 'color': [77, 194, 255],  'mass': 178.49},
    'Ta': {'number': 73, 'color': [77, 166, 255],  'mass': 180.948},
    'W':  {'number': 74, 'color': [33, 148, 214],  'mass': 183.84},
    'Re': {'number': 75, 'color': [38, 125, 171],  'mass': 186.207},
    'Os': {'number': 76, 'color': [38, 102, 150],  'mass': 190.23},
    'Ir': {'number': 77, 'color': [23, 84, 135],   'mass': 192.217},
    'Pt': {'number': 78, 'color': [208, 208, 224], 'mass': 195.078},
    'Au': {'number': 79, 'color': [255, 209, 35],  'mass': 196.967},
    'Hg': {'number': 80, 'color': [184, 184, 208], 'mass': 200.59},
    'Tl': {'number': 81, 'color': [166, 84, 77],   'mass': 204.383},
    'Pb': {'number': 82, 'color': [87, 89, 97],    'mass': 207.2},
    'Bi': {'number': 83, 'color': [158, 79, 181],  'mass': 208.98},
    'Po': {'number': 84, 'color': [171, 92, 0],    'mass': 209.0},
    'At': {'number': 85, 'color': [117, 79, 69],   'mass': 210.0},
    'Rn': {'number': 86, 'color': [66, 130, 150],  'mass': 222.0},
    'Fr': {'number': 87, 'color': [66, 0, 102],    'mass': 223.0},
    'Ra': {'number': 88, 'color': [0, 125, 0],     'mass': 226.0},
    'Ac': {'number': 89, 'color': [112, 171, 250], 'mass': 227.0},
    'Th': {'number': 90, 'color': [0, 186, 255],   'mass': 232.038},
    'Pa': {'number': 91, 'color': [0, 161, 255],   'mass': 231.036},
    'U':  {'number': 92, 'color': [0, 143, 255],   'mass': 238.029},
    'Np': {'number': 93, 'color': [0, 128, 255],   'mass': 237.0},
    'Pu': {'number': 94, 'color': [0, 107, 255],   'mass': 244.0},
    'Am': {'number': 95, 'color': [84, 92, 242],   'mass': 243.0},
    'Cm': {'number': 96, 'color': [120, 92, 227],  'mass': 247.0},
    'Bk': {'number': 97, 'color': [138, 79, 227],  'mass': 247.0},
    'Cf': {'number': 98, 'color': [161, 54, 212],  'mass': 251.0},
    'Es': {'number': 99, 'color': [179, 31, 212],  'mass': 252.0},
    'Fm': {'number': 100, 'color': [179, 31, 186],  'mass': 257.0},
    'Md': {'number': 101, 'color': [179, 13, 166],  'mass': 258.0},
    'No': {'number': 102, 'color': [189, 13, 135],  'mass': 259.0},
    'Lr': {'number': 103, 'color': [199, 0, 102],   'mass': 262.0},
    'Rf': {'number': 104, 'color': [204, 0, 89],    'mass': 261.0},
    'Db': {'number': 105, 'color': [209, 0, 79],    'mass': 262.0},
    'Sg': {'number': 106, 'color': [217, 0, 69],    'mass': 266.0},
    'Bh': {'number': 107, 'color': [224, 0, 56],    'mass': 264.0},
    'Hs': {'number': 108, 'color': [230, 0, 46],    'mass': 277.0},
    'Mt': {'number': 109, 'color': [235, 0, 38],   'mass': 268.0}
}
